# Reports for AI Agents
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/reports-for-ai-agents#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/reports-for-ai-agents#prerequisites)
  * [Available Reports](https://help.sap.com/docs/leanix/ea/reports-for-ai-agents#available-reports)


Use reports to get an overview of AI agents in your enterprise architecture landscape.
